package de.intevation.gnv.artifactdatabase.objects;

import java.util.Collection;
import java.util.Map;

/**
 * The default implementation of an <code>OutputMode</code>.
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 */
public class DefaultOutputMode implements OutputMode {

    /**
     * The UID of this Class.
     */
    private static final long serialVersionUID = 7487880486604174521L;

    /**
     * The name of the OutputMode
     */
    private String name = null;

    /**
     * The mimetype of the OutputMode
     */
    private String mimeType = null;

    /**
     * The parameters that could be used for this OutputMode
     */
    private Collection<OutputParameter> outputParameter = null;

    /**
     * The exports that can be called using this outputMode
     */
    private Map<String, ExportMode> exports;

    /**
     * Constructor
     * @param name The name of the OutputMode
     * @param mimeType The mimetype of the OutputMode
     * @param outputParameter The parameters that could be used for this OutputMode
     * @param exports The exports that can be called using this outputMode
     */
    public DefaultOutputMode(
        String name,
        String mimeType,
        Collection<OutputParameter> outputParameter,
        Map<String, ExportMode> exports)
    {
        super();
        this.name            = name;
        this.mimeType        = mimeType;
        this.outputParameter = outputParameter;
        this.exports         = exports;
    }

    public String getMimeType() {
        return this.mimeType;
    }

    public String getName() {
        return this.name;
    }

    public Collection<OutputParameter> getOutputParameters() {
        return this.outputParameter;
    }

    public ExportMode getExportMode(String mode) {
        return exports.get(mode);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
